@@ -9,7 +9,6 @@ import (
 	"net/http"
 	"os"
 	"regexp"
-	"slices"
 	"strings"
 	"time"
 
@@ -89,7 +88,8 @@ func (t *Transport) setDefaults(opts ClientOptions) {
 	if opts.EnableDebugTrace != nil {
 		t.EnableDebugTrace = *opts.EnableDebugTrace
 	} else {
-		t.EnableDebugTrace = !slices.Contains([]string{"", "0", "false"}, os.Getenv("FLY_FORCE_TRACE"))
+		v := os.Getenv("FLY_FORCE_TRACE")
+		t.EnableDebugTrace = !(v == "" || v == "0" || v == "false")
 	}
 }
 
