@@ -25,6 +25,7 @@ const (
 	MachineStateStopped                        = "stopped"
 	MachineStateCreated                        = "created"
 	DefaultVMSize                              = "shared-cpu-1x"
+	DefaultGPUVMSize                           = "performance-8x"
 )
 
 type Machine struct {
@@ -321,6 +322,7 @@ type MachineGuest struct {
 	CPUKind  string `json:"cpu_kind,omitempty"`
 	CPUs     int    `json:"cpus,omitempty"`
 	MemoryMB int    `json:"memory_mb,omitempty"`
+	GPUKind  string `json:"gpu_kind,omitempty"`
 
 	KernelArgs []string `json:"kernel_args,omitempty"`
 }
@@ -578,7 +580,7 @@ type MachineConfig struct {
 	// Deprecated: use Service.Autostart instead
 	DisableMachineAutostart *bool `json:"disable_machine_autostart,omitempty"`
 
-	HostDedicationId string `json:"host_dedication_id"`
+	HostDedicationId string `json:"host_dedication_id,omitempty"`
 }
 
 func (c *MachineConfig) ProcessGroup() string {
@@ -664,6 +666,7 @@ type LaunchMachineInput struct {
 	SkipLaunch              bool           `json:"skip_launch,omitempty"`
 	SkipServiceRegistration bool           `json:"skip_service_registration,omitempty"`
 	HostDedicationID        string         `json:"host_dedication_id,omitempty"`
+	LSVD                    bool           `json:"lsvd,omitempty"`
 
 	LeaseTTL int `json:"lease_ttl,omitempty"`
 
