@@ -105,7 +105,10 @@ func (c *Config) updateMachineConfig(src *api.MachineConfig) (*api.MachineConfig
 	}
 
 	// Metrics
-	mConfig.Metrics = c.Metrics
+	mConfig.Metrics = nil
+	if len(c.Metrics) > 0 {
+		mConfig.Metrics = c.Metrics[0].MachineMetrics
+	}
 
 	// Init
 	cmd, err := c.InitCmd(processGroup)
@@ -188,6 +191,7 @@ func (c *Config) updateMachineConfig(src *api.MachineConfig) (*api.MachineConfig
 	c.tomachineSetStopConfig(mConfig)
 
 	// Files
+	mConfig.Files = nil
 	machine.MergeFiles(mConfig, c.MergedFiles)
 
 	return mConfig, nil
