@@ -13,7 +13,6 @@ import (
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
-	"github.com/superfly/flyctl/internal/flag/flagnames"
 	"github.com/superfly/flyctl/internal/format"
 	"github.com/superfly/flyctl/internal/render"
 )
@@ -88,7 +87,8 @@ func runList(ctx context.Context) (err error) {
 
 func getOrg(ctx context.Context) (*api.Organization, error) {
 	client := client.FromContext(ctx).API()
-	orgName := flag.GetString(ctx, flagnames.Org)
+
+	orgName := flag.GetOrg(ctx)
 
 	if orgName == "" {
 		return nil, nil
