@@ -9,6 +9,7 @@ import (
 	"slices"
 	"strconv"
 	"strings"
+	"sync"
 	"time"
 
 	"github.com/samber/lo"
@@ -351,6 +352,28 @@ func (md *machineDeployment) updateExistingMachines(ctx context.Context, updateE
 		return md.updateUsingBlueGreenStrategy(ctx, updateEntries)
 	}
 
+	if md.strategy == "immediate" {
+		var wg sync.WaitGroup
+		pool := make(chan struct{}, md.immediateMaxConcurrent)
+		for i, updateEntry := range updateEntries {
+			e := updateEntry
+			indexStr := formatIndex(i, len(updateEntries))
+			wg.Add(1)
+			pool <- struct{}{}
+			go func() {
+				defer wg.Done()
+				if err := md.updateMachine(ctx, e, indexStr); err != nil {
+					if md.strategy == "immediate" {
+						fmt.Fprintf(md.io.ErrOut, "Continuing after error: %s\n", err)
+					}
+				}
+				<-pool
+			}()
+		}
+		wg.Wait()
+		return nil
+	}
+
 	var groupCount int
 	if mu := md.maxUnavailable; mu > 0 && mu < 1 {
 		groupCount = int(math.Floor(1.0 / mu))
