@@ -37,10 +37,7 @@ func create() (cmd *cobra.Command) {
 func runPlanetscaleCreate(ctx context.Context) (err error) {
 	appName := appconfig.NameFromContext(ctx)
 
-	options := extensions_core.DbExtensionDefaults
-	options.Provider = "planetscale"
-
-	extension, err := extensions_core.ProvisionExtension(ctx, appName, options)
+	extension, err := extensions_core.ProvisionExtension(ctx, appName, "planetscale", false, gql.AddOnOptions{})
 
 	if err != nil {
 		return err
