@@ -13,7 +13,7 @@ import (
 
 func Dashboard() (cmd *cobra.Command) {
 	const (
-		long = `View Sentry issues for this application`
+		long = `View application errors in the Sentry dashboard`
 
 		short = long
 		usage = "dashboard"
