@@ -2,12 +2,13 @@ package flag
 
 import (
 	"context"
+	"slices"
 	"time"
 
 	"github.com/spf13/pflag"
+	"github.com/superfly/flyctl/internal/env"
 	"github.com/superfly/flyctl/internal/flag/flagctx"
 	"github.com/superfly/flyctl/internal/flag/flagnames"
-	"golang.org/x/exp/slices"
 )
 
 // NewContext derives a context that carries fs from ctx.
@@ -118,7 +119,11 @@ func IsSpecified(ctx context.Context, name string) bool {
 
 // GetOrg is shorthand for GetString(ctx, Org).
 func GetOrg(ctx context.Context) string {
-	return GetString(ctx, flagnames.Org)
+	org := GetString(ctx, flagnames.Org)
+	if org == "" {
+		org = env.First("FLY_ORG")
+	}
+	return org
 }
 
 // GetRegion is shorthand for GetString(ctx, Region).
@@ -166,3 +171,7 @@ func GetFlagsName(ctx context.Context, ignoreFlags []string) []string {
 
 	return flagsName
 }
+
+func GetProcessGroup(ctx context.Context) string {
+	return GetString(ctx, flagnames.ProcessGroup)
+}
